@@ -1,10 +1,10 @@
 """Simple gradient computation library for Python."""
 
 from numgrad._config import Config, config  # noqa: F401
-from numgrad._decorators import differentiable
 from numgrad._differentiable import Differentiable, grad, value_and_grad
 from numgrad._graph import Graph
 from numgrad._variable import Variable
+from numgrad._vjp import differentiable
 
 from numgrad import _numpy, _scipy  # noqa: F401, I100, I202
 
